@@ -7,9 +7,11 @@ LastEditTime: 2022.02.02 18:14
 import click
 from click_aliases import ClickAliasedGroup
 
+from .alias import alias as _alias
 from .clash import clash as _clash
 from .hosts import hosts as _hosts
-from .notes import new_article as _new_article
+from .notes import notes as _notes
+from .powershell import powershell as _powershell
 from .python import python as _python
 
 
@@ -48,10 +50,39 @@ def clash():
 @command_ccf.command(
     aliases=["nn"],
     context_settings={"help_option_names": ["-h", "--help"]},
-    help="Create a new article for hugo.",
+    help="Create a new note for hugo.",
 )
 @click.option(
-    "--path", "-p", required=True, type=str, help="The file path for a new article."
+    "--path", "-p", required=True, type=str, help="The file path for a new note."
 )
 def notes(path):
-    _new_article(path)
+    _notes(path)
+
+
+@command_ccf.command(
+    aliases=["ps"],
+    context_settings={"help_option_names": ["-h", "--help"]},
+    help="Create or display configuration files about PowerShell.",
+)
+@click.option(
+    "--write/--read",
+    "-w/-r",
+    default=False,
+    help="Read only or create configuration files.",
+)
+def powershell(write):
+    _powershell(not write)
+
+
+@command_ccf.command(
+    context_settings={"help_option_names": ["-h", "--help"]},
+    help="Generate aliases for powershell or bash configuration files.",
+)
+@click.option(
+    "--write/--read",
+    "-w/-r",
+    default=False,
+    help="Read only or write to configuration files.",
+)
+def alias(write):
+    _alias(not write)
